name property
Route name, unique across the whole router — used for context.goNamed
and for resolving the active level from the current path.
Implementation
final String name;
Route name, unique across the whole router — used for context.goNamed
and for resolving the active level from the current path.
final String name;