CacheContainer class

Constructors

CacheContainer(int maxSize)

Properties

cacheHits ↔ int
getter/setter pair
data → LinkedHashMap<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
hitRate → double
no setter
maxSize ↔ int
Максимальный размер. Не final: может быть переопределён через CacheManager.configureMaxSize уже после создания контейнера.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalRequests ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordHit() → void
recordMiss() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited