CacheManager class abstract

LRU-кэш для нескольких именованных кэшей адаптивной навигации.

Implementers

Constructors

CacheManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAllByPrefix(String prefix) → void
clearAllCaches() → void
clearCache(CacheName cacheName) → void
configureMaxSize(CacheName cacheName, int maxSize) → void
getAllStats() → Map<CacheName, CacheStats>
getOrCompute<T>({required CacheKey key, required T compute()}) → T
getStats(CacheName cacheName) → CacheStats
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited