CacheStats class

Constructors

CacheStats({required CacheName cacheName, required int size, required int maxSize, required double hitRate, required String efficiencyLevel})
const
CacheStats.empty(CacheName cacheName)
factory

Properties

cacheName → CacheName
final
efficiencyLevel → String
final
hashCode → int
The hash code for this object.
no setterinherited
hitRate → double
final
maxSize → int
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
usagePercentage → double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited