NavigationConstants class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- level2SegmentIndex → const int
- level3SegmentIndex → const int
- level4SegmentIndex → const int
- minVisibleFeatures → const int
- restorationId → const String
- restorationScopeId → const String
- widthChangeDebounceDuration → const Duration
- widthChangeThreshold → const double
- Порог изменения ширины для обновления layout, в пикселях.