DisplayMode enum

Режим отображения навигации

Inheritance
Available extensions

Values

floatingPanel → const DisplayMode

Плавающая панель level1 (узкий экран с level1/level2)

singleColumn → const DisplayMode

Одноколоночный режим (узкий экран)

singleColumnWithBottomNav → const DisplayMode

Одноколоночный режим с нижней навигацией (узкий экран, navigation снизу)

fixedMultiColumn → const DisplayMode

Многоколоночный режим с фиксированными размерами

resizableMultiColumn → const DisplayMode

Многоколоночный режим с изменяемыми размерами (SplitPane)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DisplayMode>
A constant List of the values in this enum, in order of their declaration.