FeatureMultilevelRules class abstract

Per-feature rules for which levels/placeholders are visible at each column-count display mode, given the active navigation depth.

Implementers

Constructors

FeatureMultilevelRules()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fourColumnVisibility(int activeDepth) → VisibilityMap
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
singleColumnVisibility(int activeDepth) → VisibilityMap
threeColumnVisibility(int activeDepth) → VisibilityMap
toString() → String
A string representation of this object.
inherited
twoColumnVisibility(int activeDepth) → VisibilityMap

Operators

operator ==(Object other) → bool
The equality operator.
inherited