MultilevelLayoutRule class

The current display rule: mode plus level visibility. Get one via context.multilevelLayoutState / context.multilevelLayoutStateOnce, from a widget below MultilevelNavigatorProvider.

Constructors

MultilevelLayoutRule({required String path, required double width, required DisplayMode displayMode, required VisibilityMap visibleLevels})
const

Properties

displayMode → DisplayMode
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibleLevels → VisibilityMap
final
width → double
final

Methods

copyWith({String? path, double? width, DisplayMode? displayMode, VisibilityMap? visibleLevels}) → MultilevelLayoutRule
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited