VisibilityMap class

Constructors

VisibilityMap({required bool level1, required bool level2, required bool level3, required bool level4, required bool placeholder1, required bool placeholder2, required bool placeholder3})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isLevel1Visible → bool
no setter
isLevel2Visible → bool
no setter
isLevel3Visible → bool
no setter
isLevel4Visible → bool
no setter
level1 → bool
final
level2 → bool
final
level3 → bool
final
level4 → bool
final
placeholder1 → bool
final
placeholder2 → bool
final
placeholder3 → bool
final
placeholderLevels → List<Level>
no setter
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
regularLevels → List<Level>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({bool? level1, bool? level2, bool? level3, bool? level4, bool? placeholder1, bool? placeholder2, bool? placeholder3}) → VisibilityMap
getVisibleLevels() → List<Level>
isVisible(Level level) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLevelVisible(int levelNumber, bool visible) → VisibilityMap
showUpToLevel(int maxLevel) → VisibilityMap
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

empty → const VisibilityMap