toString method

  1. @override
String toString()

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'VisibilityMap(level1: $level1, level2: $level2, level3: $level3, level4: $level4, '
      'placeholder1: $placeholder1, placeholder2: $placeholder2, placeholder3: $placeholder3)';
}