ValidationUtils class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
isValidBasePath(String basePath)
→ bool
-
Must not start/end with
/, contain spaces, backslashes, or /.
-
isValidPath(String path)
→ bool
-
Must start with
/, not end with /, no spaces/backslashes. Empty is
allowed (level2's default path).