ModalDialogOptions class

Constructors

ModalDialogOptions({bool useSafeArea = true, AnimationStyle? animationStyle})
const

Properties

animationStyle → AnimationStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useSafeArea → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited