LevelsWidthState class

Состояние ширин уровней для всех фич

Constructors

LevelsWidthState({required Map<String, LevelsWidth> featureWidths})
const

Properties

featureWidths → Map<String, LevelsWidth>
Map: имя фичи → ширина уровней
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({Map<String, LevelsWidth>? featureWidths}) → LevelsWidthState
Создает копию с измененными значениями
getLevelsWidthForFeature(String featurePath) → LevelsWidth
Получить ширину для конкретной фичи
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited