LevelsWidthUpdateEvent class

Событие обновления ширин для фичи

Inheritance

Constructors

LevelsWidthUpdateEvent({required String name, required LevelsWidth levelsWidth})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
levelsWidth → LevelsWidth
Ширина уровней
final
name → String
Имя фичи
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited