toString method

  1. @override
String toString()

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'MultilevelState(path: $path, width: $width, displayMode: $displayMode, '
      'visibleLevels: $visibleLevels, isLevel2Collapsed: $isLevel2Collapsed, '
      'isLevel2InLayout: $isLevel2InLayout, isLevel4Collapsed: $isLevel4Collapsed, '
      'isLevel3PreservedInLayout: $isLevel3PreservedInLayout, '
      'isLevel4PreservedInLayout: $isLevel4PreservedInLayout, '
      'isLevel3MobileCollapsed: $isLevel3MobileCollapsed, '
      'isLevel4MobileCollapsed: $isLevel4MobileCollapsed)';
}