NavigationLayout class
Результат вычисления navigation layout Содержит информацию о том, как должны быть расположены уровни навигации
Constructors
-
const
Properties
- baseLevel → Level
-
Базовый уровень (основной контент)
final
- canShowLevel4Column → bool
-
Возможность показа 4-й колонки
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
overlayLevels
→ List<
Level> -
Уровни для отображения в overlay (модальные окна, выдвижные панели)
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Уровни для отображения в sidebar (боковая панель)
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{Level? baseLevel, List< Level> ? sidebarLevels, List<Level> ? overlayLevels, bool? canShowLevel4Column}) → NavigationLayout - Создать копию с изменениями
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited