features/multilevel_layout/presentation/widgets/split/split_pane library

Classes

DefaultSplitter
SplitPane
A widget that takes a list of children, lays them out along axis, and allows the user to resize them.