SplitPane class final
A widget that takes a list of children, lays them out along axis, and allows the user to resize them.
The user can customize the amount of space allocated to each child by dragging a divider between them.
initialFractions defines how much space to give each child when building this widget.
minSizes defines the minimum size that each child can be set to when adjusting the sizes of the children.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SplitPane
Constructors
-
SplitPane({required Axis axis, required List<
Widget> children, required List<double> initialFractions, Key? key, List<double> ? minSizes, List<PreferredSizeWidget> ? splitters, void onSizesChanged(List<double> sizes)?, Duration collapseAnimationDuration = const Duration(milliseconds: 260)}) -
Builds a split oriented along
axis.
Properties
- axis → Axis
-
The main axis the children will lay out on.
final
-
children
→ List<
Widget> -
The children that will be laid out along axis.
final
- collapseAnimationDuration → Duration
-
Duration of the collapse/expand animation when initialFractions change.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initialFractions
→ List<
double> -
The fraction of the layout to allocate to each child in children.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
minSizes
→ List<
double> ? -
The minimum size each child is allowed to be.
final
-
onSizesChanged
→ void Function(List<
double> sizes)? -
Callback called when the sizes of children change.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
splitters
→ List<
PreferredSizeWidget> ? -
Splitter widgets to divide children.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
dividerKey(
int index) → Key -
The key passed to the divider between children
indexand childrenindex + 1. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
axisFor(
BuildContext context, double horizontalAspectRatio) → Axis