TabConfiguration class

Annotations

Constructors

TabConfiguration({required String name, required String title, required IconData icon, required Widget content})
const

Properties

content → Widget
final
hashCode → int
The hash code for this object.
no setteroverride
icon → IconData
final
name → String
Unique tab name, also used as its query parameter value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override