TabManagerConfiguration class
Constructors
-
TabManagerConfiguration(Type pageType, {required List<
TabConfiguration> tabs, String defaultTabName = '', TabController? tabController}) -
pageTypeis used to auto-derive a unique queryParameter name.
Properties
- defaultTabName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- queryParameter → String
-
Query parameter name used to store the active tab.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tabController → TabController?
-
Auto-created if not provided.
final
-
tabs
→ List<
TabConfiguration> -
final
Methods
-
getTabByIndex(
int index) → TabConfiguration? -
getTabByName(
String tabName) → TabConfiguration? -
getTabIndex(
String tabName) → int -
getTabName(
int index) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited