FeatureStateScope class

A feature scope that:

  • stays mounted across feature switches (pair with Offstage/Stack)
  • caches the last MultilevelState for this feature
  • freezes providers so its BLoCs aren't recreated on every build

providers must be static for the feature (not depend on context).

Inheritance

Constructors

FeatureStateScope({required String featureKey, required bool isActive, required MultilevelState activeState, required List<SingleChildWidget> providers, required Widget builder(BuildContext context, MultilevelState state), Key? key})
const

Properties

activeState → MultilevelState
final
builder → Widget Function(BuildContext context, MultilevelState state)
final
featureKey → String
final
hashCode → int
The hash code for this object.
no setterinherited
isActive → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
providers → List<SingleChildWidget>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FeatureStateScope>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited