MultilevelTabPage class

Scaffold wrapper that wires a TabManagerConfiguration into its TabController and syncs the active tab with the route's query params.

Inheritance

Constructors

MultilevelTabPage({required TabManagerConfiguration configuration, Key? key, PreferredSizeWidget? appBar, Widget? floatingActionButton, Widget? drawer, Widget? endDrawer, Widget? bottomNavigationBar, Color? backgroundColor, bool resizeToAvoidBottomInset = true, Map<String, String>? additionalQueryParams})
const

Properties

additionalQueryParams → Map<String, String>?
final
appBar → PreferredSizeWidget?
final
backgroundColor → Color?
final
bottomNavigationBar → Widget?
final
configuration → TabManagerConfiguration
final
drawer → Widget?
final
endDrawer → Widget?
final
floatingActionButton → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
resizeToAvoidBottomInset → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MultilevelTabPage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited