FeatureConfigurationResolver class
Resolves the active level2/level3/level4 configuration for a path.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolveFeatureConfiguration(
String currentPath, List< FeatureNavigationConfiguration> authFeatures) → CurrentFeatureConfiguration?