CacheManagerImpl class

Implemented types

Constructors

CacheManagerImpl({Map<CacheName, int>? defaultMaxSizes})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAllByPrefix(String prefix) → void
override
clearAllCaches() → void
override
clearByPrefix(CacheName cacheName, String prefix) → void
clearCache(CacheName cacheName) → void
override
configureMaxSize(CacheName cacheName, int maxSize) → void
override
getAllStats() → Map<CacheName, CacheStats>
override
getOrCompute<T>({required CacheKey key, required T compute()}) → T
override
getStats(CacheName cacheName) → CacheStats
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited