RouterParams class final
Constructors
- RouterParams.base()
-
const
- RouterParams.from({String? initialLocation, String? onGlobalRedirect(Uri uri)?})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialLocation → String?
-
final
- onGlobalRedirect → String? Function(Uri uri)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited