closeModal method
Removes modalId from the modal query parameter, dropping the
parameter entirely if it was the last one open.
Implementation
void closeModal(String modalId) {
NavigationUtils.closeModal(router, modalId);
}
Removes modalId from the modal query parameter, dropping the
parameter entirely if it was the last one open.
void closeModal(String modalId) {
NavigationUtils.closeModal(router, modalId);
}