MultilevelModalManager class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
registeredModals
→ List<
String> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
get(
String id) → MultilevelModalBuilderAbstraction? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
MultilevelModalBuilderAbstraction builder) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unregister(
String id) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited