LevelsWidth class
User-saved column widths for one feature's levels.
Constructors
- LevelsWidth({double? level1Width, double? level2Width, double? level3Width, double? level4Width})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- level1Width → double?
-
final
- level2Width → double?
-
final
- level3Width → double?
-
final
- level4Width → double?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{double? level1Width, double? level2Width, double? level3Width, double? level4Width}) → LevelsWidth -
getWidthForLevel(
Level level) → double? -
getWidthsForVisibleLevels(
List< Level> visibleLevels) → Map<Level, double> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String - A string representation of this object.
-
updateWidthForLevel(
Level level, double width) → LevelsWidth
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited