CurrentFeatureConfiguration class

The level2/level3/level4 configuration active for the current path.

Properties

hashCode → int
The hash code for this object.
no setterinherited
level2 → FeatureLevelItemConfiguration?
final
level3 → FeatureLevelItemConfiguration?
final
level4 → FeatureLevelItemConfiguration?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited