RouteBuilder class
Построитель маршрутов для фич Отвечает только за создание маршрутов согласно конфигурации
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildBranch(
FeatureNavigationConfiguration feature, FeatureNavigationConfiguration defaultUnauthorizedFeature, AuthenticationStateNotifier authenticationStateNotifier) → StatefulShellBranch -
buildUnauthRoute(
FeatureNavigationConfiguration unauthFeature, FeatureNavigationConfiguration defaultAuthorizedFeature, AuthenticationStateNotifier authenticationStateNotifier) → UnauthRoute